/**
 ****************************************************************************
 * @file	 D_Para.h
 * @brief	 Motor vector control Parameter Header File for CH2
 * @version  V1.0
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#ifndef _D_PARA_CH2_H
#define _D_PARA_CH2_H

#undef	__TYPE_LOW_VOLT
#undef	__TYPE_HIGH_VOLT

#undef USE_FAN_MOTOR

/*===================================================================*
	  Select Board type (Only valid in V7Z board)
 *===================================================================*/
#define	__TYPE_LOW_VOLT									/* Low voltage board */
//#define	__TYPE_HIGH_VOLT								/* High voltage board */

/*===================================================================*
	  Select parts
 *===================================================================*/
//#define	__USE_ENCODER_CH2								/* If define __USE_ENCODER, use encoder */
//#define	__USE_VE_CH2									/* If define __USE_VE, use Vector Engine */

/*===================================================================*
	  Board Parameter Definition
 *===================================================================*/
/******** V7Z Low voltage board ***********************/
#if defined(__TYPE_LOW_VOLT)
  /* High/Low side driver logic */
  #define	cPOLH_CH2				(1)					/* High side	 0:Low active, 1:High active */
  #define	cPOLL_CH2				(1)					/* Low	side	 0:Low active, 1:High active */

  /* V MAX */
  #define	cV_MAX_CH2				(80.0f)				/* [V] Input voltage(Vdc)  at ADC =0xFFF0(5V) */

  /* A MAX */
  #define	cA_MAX_CH2				(14.9f)				/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */
//  #define	cA_MAX_CH2				(52.0f)				/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */

/******** V7Z High voltage board **********************/
#elif defined(__TYPE_HIGH_VOLT)
  /* High/Low side driver logic */
  #define	cPOLH_CH2				(1)					/* High side	 0:Low active, 1:High active */
  #define	cPOLL_CH2				(1)					/* Low	side	 0:Low active, 1:High active */

  /* V MAX */
  #define	cV_MAX_CH2				(473.0f)			/* [V] Input voltage(Vdc)  at ADC =0xFFF0(5V) */

  /* A MAX */
  #define	cA_MAX_CH2				(16.1f)				/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */
//  #define	cA_MAX_CH2				(8.32f)				/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */
#endif

/* Current detection Type */
#define	cSHUNT_TYPE_CH2 			(3)					/* 1 : 1-shunt, 3 : 3-shunt */
#define	cBOOT_TYPE_CH2				(cBoot_i)			/* cBoot_i : Current control, cBoot_v: Volt control */
//#define	cSHUNT_TYPE_CH2 			(1)					/* 1 : 1-shunt, 3 : 3-shunt */
//#define	cBOOT_TYPE_CH2				(cBoot_v)			/* cBoot_i : Current control, cBoot_v: Volt control */

#define	cSHUNT_ZERO_OFFSET_CH2		(2.5f)				/* [V] Shunt ad offset voltage (shunt ad voltage of 0A) */

/* AD Channel */
#if !defined(__USE_INAMP_CH2)
  #define	cADCH_CURRENT_U_CH2		(3)					/* AD channel for U-phase current of 3shunt */
  #define	cADCH_CURRENT_V_CH2		(4)					/* AD channel for V-phase current of 3shunt */
  #define	cADCH_CURRENT_W_CH2		(5)					/* AD channel for W-phase current of 3shunt */
  #define	cADCH_CURRENT_IDC_CH2	(5)					/* AD Channel for DC current of 1shunt */
#else
  #define	cADCH_CURRENT_U_CH2		(3)					/* AD channel for U-phase current of 3shunt */
  #define	cADCH_CURRENT_V_CH2		(4)					/* AD channel for V-phase current of 3shunt */
  #define	cADCH_CURRENT_W_CH2		(5)					/* AD channel for W-phase current of 3shunt */
  #define	cADCH_CURRENT_IDC_CH2	(5)					/* AD Channel for DC current of 1shunt */
#endif /* __USE_INAMP_CH2 */

#define	cADCH_VDC_CH2			    (1)					/* AD Channel for power supply voltage */

/* Over current */
#define	cOVC_CH2					(5.00f)				/* [A] Over current  */

/* Over voltage */
#define	cVDC_MINLIM_CH2				(1.0f)				/* [V] Vdc min limit */
#define	cVDC_MAXLIM_CH2				(cV_MAX_CH2 - 1.0f)	/* [V] Vdc max limit */

/*===================================================================*
	  Motor Parameter Definition
 *===================================================================*/
#if defined(__TYPE_HIGH_VOLT)
 #define USE_FAN_MOTOR
#endif

/* PWM Parameter */
#if defined(USE_FAN_MOTOR)
#define	cPWMPRD_CH2 				(64.0f)				/* [us] PWM Period */
#define	cDEADTIME_CH2				(1.5f)				/* [us] Dead time */
#define	cREPTIME_CH2				(1)					/* Repeat time */
#else
#define	cPWMPRD_CH2 				(62.5f)				/* [us] PWM Period */
#define	cDEADTIME_CH2				(1.0f)				/* [us] Dead time */
#define	cREPTIME_CH2				(1)					/* Repeat time */
#endif

/* External specification */
#if defined(USE_FAN_MOTOR)
#define	cSPEED_ACT_CH2				(150.0f)			/* [Hz or RPM] Target speed of motor */
#else
#define	cSPEED_ACT_CH2				(100.0f)			/* [Hz or RPM] Target speed of motor */
#endif

#if defined(USE_FAN_MOTOR)
#define	cID_ST_USER_ACT_CH2			(1.0f)				/* [A] Start current (Id) */
#define	cIQ_ST_USER_ACT_CH2			(0.5f)				/* [A] Start current (Iq) */
#else
#define	cID_ST_USER_ACT_CH2			(1.0f)				/* [A] Start current (Id) */
#define	cIQ_ST_USER_ACT_CH2			(0.9f)				/* [A] Start current (Iq) */
#endif

/* Motor Parameter */
#if defined(USE_FAN_MOTOR)
#define	cMOTOR_R_CH2				(12.862f)			/* [Ohm] Winding resistance */
#define	cMOTOR_LQ_CH2				(3.041f)			/* [mH] q-axis inductance */
#define	cMOTOR_LD_CH2				(cMOTOR_LQ_CH2)		/* [mH] d-axis inductance */
#define	cPOLE_CH2					(8)					/* [Pole] Poles of the motor */
#else
#define	cMOTOR_R_CH2				(1.0f)				/* [Ohm] Winding resistance */
#define	cMOTOR_LQ_CH2				(1.0f)				/* [mH] q-axis inductance */
#define	cMOTOR_LD_CH2				(cMOTOR_LQ_CH2)		/* [mH] d-axis inductance */
#define	cPOLE_CH2					(8)					/* [Pole] Poles of the motor */
#endif

/* Control Gain constant */
#if defined(USE_FAN_MOTOR)
#define	cID_KP_CH2					(22.0f)				/* [V/A]  d-axis current control Proportinal gain */
#define	cID_KI_CH2					(1000.0f)			/* [V/As] d-axis current control Integral gain */
#else
#define	cID_KP_CH2					(0.3f)				/* [V/A]  d-axis current control Proportinal gain */
#define	cID_KI_CH2					(450.0f)			/* [V/As] d-axis current control Integral gain */
#endif
#define	cIQ_KP_CH2					(cID_KP_CH2)		/* [V/A]  q-axis current control Proportinal gain */
#define	cIQ_KI_CH2					(cID_KI_CH2)		/* [V/As] q-axis current control Integral gain */

#if defined(USE_FAN_MOTOR)
#define	cPOSITION_KP_CH2			(1.10046f)			/* [Hz/V]  Position estimation Proportinal gain (Kp) */
#define	cPOSITION_KI_CH2			(0.71398f)			/* [Hz/Vs] Position estimation Integral gain (Ki) */
#define	cSPEED_KP_CH2				(0.02f)				/* [A/Hz]  Speed Control Proportinal gain */
#define	cSPEED_KI_CH2				(0.03f)				/* [A/Hzs] Speed Control Integral gain */
#else
#define	cPOSITION_KP_CH2			(17.0f)				/* [Hz/V]  Position estimation Proportinal gain (Kp) */
#define	cPOSITION_KI_CH2			(40.0f)				/* [Hz/Vs] Position estimation Integral gain (Ki) */
#define	cSPEED_KP_CH2				(0.05f)				/* [A/Hz]  Speed Control Proportinal gain */
#define	cSPEED_KI_CH2				(0.13f)				/* [A/Hzs] Speed Control Integral gain */
#endif

#define	cSPD_PI_PRD_CH2				(1)					/* Speed PI period */

#if defined(USE_FAN_MOTOR)
#define	cFCD_UD_LIM_CH2				(20.0f)				/* [Hz/s] Limitation of the increase value (Forced Stage) */
#define	cSTD_UP_LIM_CH2				(20.0f)				/* [Hz/s] Limitation of the increase value (Steady Stage) */
#define	cSTD_DW_LIM_CH2				(20.0f)				/* [Hz/s] Limitation of the decrease value (Steady Stage) */
#else
#define	cFCD_UD_LIM_CH2				(15.0f)				/* [Hz/s] Limitation of the increase value (Forced Stage) */
#define	cSTD_UP_LIM_CH2				(10.0f)				/* [Hz/s] Limitation of the increase value (Steady Stage) */
#define	cSTD_DW_LIM_CH2				(10.0f)				/* [Hz/s] Limitation of the decrease value (Steady Stage) */
#endif

#define	cBOOT_LEN_CH2				(0.5f)				/* [s] Time of Bootstrap Stage */
#define	cINIT_LEN_CH2				(0.5f)				/* [s] Time of Positioning Stage */
#define	cINIT_WAIT_LEN_CH2			(0.5f)				/* [s] Time of Positioning wait time */
#define	cGOUP_DELAY_LEN_CH2			(0.01f)				/* [s] Time of Change-up delay time */

#if defined(USE_FAN_MOTOR)
#define	cHZ_MAX_CH2 				(200.0f)	    	/* [Hz] Maximum speed of motor */
#define	cHZ_MIN_CH2 				(40.0f)	    		/* [Hz] Minimam speed of motor */
#else
#define	cHZ_MAX_CH2 				(500.0f)	    	/* [Hz] Maximum speed of motor */
#define	cHZ_MIN_CH2 				(60.0f)	    		/* [Hz] Minimam speed of motor */
#endif
														/* When set cHZ_MIN > S_speed_actx, not move Stage from Force */

#define	cHZ_SPWM_CH2				(100.0f)			/* [Hz] in Hz the rotating speed under which the shift PWM will work (for VE 1shunt) */
#define	cMINPLS_CH2					(2.0f)				/* [us] Minimum Pulse (for 1shunt) */
#define	cMAXPLS_CH2					(cPWMPRD_CH2 * 0.9f)	/* [us] Maximum Pulse (for 3shunt) */

#define	cID_LIM_CH2 				(cOVC_CH2 * 0.9f) 	/* [A] d-axis limitation current */
#define	cIQ_LIM_CH2 				(cOVC_CH2 * 0.9f) 	/* [A] q-axis limitation current */

#define	cINITIAL_POSITION_CH2		(0)					/* [deg] Initial position */

#if (cSHUNT_TYPE_CH2 == 3)
  #define	cTRG_COMP_CH2			(0.0f)  			/* [us] Trigger compensation time for 3shunt(for SoftVector). Setting range:0 <= x < (cPWMPRD_CH2/2) */
#else
  #define	cTRG_COMP_CH2			(-1.0f)				/* [us] Trigger compensation time for 1shunt(for SoftVector). Setting range:(-cPWMPRD_CH2/2) < x < (cPWMPRD_CH2/2) */
#endif

/*for Voltage control parameter */
#if defined(USE_FAN_MOTOR)
#define	cVD_POS_CH2					(0.8f)				/* [V] Voltage of positioning */
#define	cSPD_COEF_CH2				(0.2f)				/* [-] Speed coefficient */
#define	cHZ_V2I_CH2					(cHZ_MAX_CH2 - 1.0f)/* [Hz] Speed of switching from voltage control to current control */
#else
#define	cVD_POS_CH2					(0.6f)				/* [V] Voltage of positioning */
#define	cSPD_COEF_CH2				(0.15f)				/* [-] Speed coefficient */
#define	cHZ_V2I_CH2					(100.0f)			/* [Hz] Speed of switching from voltage control to current control */
#endif

/* for Encoder parameter */
#define	cENC_PULSE_NUM_CH2			(2048)				/* [ppr] Number of Encoder pulse */
#define	cENC_DEG_ADJUST_CH2			(180)				/* [deg] Adjust Z-phase,0deg of electrical-angle */

#define	cENC_NOISE_TIME_CH2			(0.1f)				/* [us] Encoder signal input noise cancel time. unit:fc/8 (for A-ENC only) */

/* for Fixed Vdc parameter */
#define __FIXED_VDC_CH2 			(0)					/* Fixed Vdc */
#define	cVDC_CH2					(24.0f)	//(141.0f)			/* [V] Power Voltage */



/*===================================================================*/
/* Control period of motor */
#define	cCTRL_PRD_CH2				(cPWMPRD_CH2 * cREPTIME_CH2 * 1e-6)								/* [s] */
#define	cSPD_CTRL_PRD_CH2			(cSPD_PI_PRD_CH2 * cPWMPRD_CH2 * cREPTIME_CH2 * 1e-6)			/* [s] */


/*===================================================================*
	Parameter check
 *===================================================================*/
#if defined(__TMPM4KNA_H__)
  #if defined(__USE_VE_CH2)
    #error M4KNA do not have the VE CH2.
  #endif
#endif /* __TMPM4KNA_H__ */

#if (!((cPOLH_CH2 == 0) || (cPOLH_CH2 == 1)))
#error cPOLH_CH2 define error. cPOLH_CH2 only 0 or 1.
#endif
#if (!((cPOLL_CH2 == 0) || (cPOLL_CH2 == 1)))
#error cPOLL_CH2 define error. cPOLL_CH2 only 0 or 1.
#endif


#if (!((cSHUNT_TYPE_CH2 == 1) || (cSHUNT_TYPE_CH2 == 3)))
#error cSHUNT_TYPE_CH2 define error. cSHUNT_TYPE_CH2 only 1 or 3.
#endif

#if defined(__TYPE_LOW_VOLT) && defined(__TYPE_HIGH_VOLT)
#error __TYPE_LOW_VOLT or __TYPE_HIGH_VOLT define error.
#endif

#endif /* _D_PARA_CH2_H */

/*************************** END OF FILE **************************************/

